﻿using UnityEngine;
using System.Collections;
using UnityEngine.Events;

public class Player : MonoBehaviour {
	public static Player instance;
	public PlayerInfo playerInfo;
	public PlayerInfoChangedEvent playerInfoChanged;
	public ItemRemovedEvent inventoryItemRemoved;

	InventoryItem[] Items = new InventoryItem[]{
		new InventoryItem("Bow",250,1000),
		new InventoryItem("Gun",500,2000),
		new InventoryItem("Rabbit Skin",10,5),
		new InventoryItem("Leather Scrap",20,15),
		new InventoryItem("Apple",1,2),
		new InventoryItem("Iron Ore",25,100),
		new InventoryItem("Booster Spice",1,5000)
	};

	void Awake()
	{
		if(instance != null)
		{
			DestroyImmediate(gameObject);
			return;
		}

		instance = this;
		DontDestroyOnLoad(this); // Only needed if you want the object to persist between scene changes.
	}

	void Start()
	{
		playerInfo = PlayerInfo.Load();
		playerInfoChanged.Invoke(playerInfo);
	}

//	void OnDisable()
//	{
//		playerInfo.Save();
//	}
		
	public void SetName(string newName)
	{
		playerInfo.playerName = newName;
		playerInfoChanged.Invoke(playerInfo);
		playerInfo.Save();
	}

	public void AddInventoryItem()
	{
		playerInfo.inventory.Add(Items[Random.Range(0, Items.Length)]);
		playerInfoChanged.Invoke(playerInfo);
		playerInfo.Save();
	}

	public void RemoveInventoryItem()
	{
		if(playerInfo.inventory.Count == 0) return;
		var item =  playerInfo.inventory[Random.Range(0, playerInfo.inventory.Count)];
		inventoryItemRemoved.Invoke(item);
		playerInfo.inventory.Remove(item);
		playerInfoChanged.Invoke(playerInfo);
		playerInfo.Save();
	}
}

[System.Serializable]
public class PlayerInfoChangedEvent : UnityEvent<PlayerInfo>
{

}

[System.Serializable]
public class ItemRemovedEvent : UnityEvent<InventoryItem>
{

}